/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 *
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.tools.signature.bean;


import android.text.TextUtils;

import com.compdfkit.core.signature.CPDFOwnerInfo;
import com.compdfkit.core.signature.CPDFX509;

import java.util.ArrayList;
import java.util.List;

public class CPDFOwnerItemData {

    public CPDFOwnerItemData() {

    }

    public CPDFOwnerItemData(CPDFX509 cpdfx509){
        this.cpdfx509 = cpdfx509;
        StringBuilder builder = new StringBuilder();
        CPDFOwnerInfo ownerInfo = cpdfx509.getCertInfo().getSubject();
        List<String> infos = new ArrayList<>();
        if (!TextUtils.isEmpty(ownerInfo.getCountry())){
            infos.add("C="+ownerInfo.getCountry());
        }
        if (!TextUtils.isEmpty(ownerInfo.getOrgnize())){
            infos.add("O="+ownerInfo.getOrgnize());
        }
        if (!TextUtils.isEmpty(ownerInfo.getOrgnizeUnit())){
            infos.add("OU="+ownerInfo.getOrgnizeUnit());
        }
        if (!TextUtils.isEmpty(ownerInfo.getCommonName())){
            infos.add("CN="+ownerInfo.getCommonName());
        }
        for (int i = 0; i < infos.size(); i++) {
            String item = infos.get(i);
            builder.append(item);
            if (i != infos.size() -1){
                builder.append(",");
            }
        }
        this.content = builder.toString();
    }

    private CPDFX509 cpdfx509;

    private String content;

    private boolean isExpanded = true;

    private boolean hasParent;

    public CPDFX509 getCpdfx509() {
        return cpdfx509;
    }

    public void setCpdfx509(CPDFX509 cpdfx509) {
        this.cpdfx509 = cpdfx509;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public void setExpanded(boolean expanded) {
        isExpanded = expanded;
    }

    public boolean isExpanded() {
        return isExpanded;
    }

    public void setHasParent(boolean hasParent) {
        this.hasParent = hasParent;
    }

    public boolean isHasParent() {
        return hasParent;
    }
}
