package com.compdfkit.tools.signature.pdfproperties.pdfsign;


import android.content.Context;
import android.graphics.Bitmap;
import android.text.TextUtils;
import android.util.AttributeSet;
import android.view.Gravity;
import android.widget.FrameLayout;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.annotation.StringRes;
import androidx.appcompat.widget.AppCompatImageView;
import androidx.appcompat.widget.AppCompatTextView;
import androidx.constraintlayout.widget.ConstraintLayout;
import androidx.constraintlayout.widget.ConstraintSet;
import androidx.transition.TransitionManager;

import com.compdfkit.tools.R;
import com.compdfkit.tools.common.utils.date.CDateUtil;
import com.compdfkit.tools.common.utils.glide.GlideApp;
import com.compdfkit.tools.common.utils.image.CBitmapUtil;

public class CDigitalSignStylePreviewView extends FrameLayout {

    private AppCompatImageView ivSignImage;

    private AppCompatTextView tvSignInfo;

    private AppCompatImageView ivLogo;

    private ConstraintLayout clPreview;

    private CDigitalSignStyleData previewData;

    private ConstraintLayout clRoot;

    private ConstraintSet constraintSet = new ConstraintSet();

    private boolean showName = false;

    private boolean showDate = false;

    private boolean showLogo = false;

    private boolean showDistinguishableName;

    private boolean showSDKVersion;

    private boolean showTab;

    private boolean showPosition;

    private boolean showReason;

    public CDigitalSignStylePreviewView(@NonNull Context context) {
        this(context, null);
    }

    public CDigitalSignStylePreviewView(@NonNull Context context, @Nullable AttributeSet attrs) {
        this(context, attrs, 0);
    }

    public CDigitalSignStylePreviewView(@NonNull Context context, @Nullable AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        initView(context);
    }

    private void initView(Context context) {
        inflate(context, R.layout.tools_sign_style_preview_view, this);
        ivSignImage = findViewById(R.id.iv_sign);
        tvSignInfo = findViewById(R.id.tv_sign_info);
        ivLogo = findViewById(R.id.iv_logo);
        clPreview = findViewById(R.id.cl_preview);
        clRoot = findViewById(R.id.cl_root);
        constraintSet.clone(clPreview);
    }

    public void setPreviewData(CDigitalSignStyleData data) {
        previewData = data;
        update();
    }

    private void setSignImage(String signImagePath) {
        previewData.setSignImagePath(signImagePath);
        update();
    }

    public void setShowName(boolean show) {
        this.showName = show;
        update();
    }

    public void setShowTab(boolean show) {
        this.showTab = show;
        update();
    }

    public void setShowSDKVersion(boolean show) {
        this.showSDKVersion = show;
        update();
    }

    public void setShowDate(boolean show) {
        if (previewData != null) {
            previewData.setDate(show ? CDateUtil.getDataTime(CDateUtil.NORMAL_DATE_FORMAT_1) : "");
        }
        this.showDate = show;
        update();
    }

    public void setShowLogo(boolean show) {
        this.showLogo = show;
        update();
    }

    public void setShowDistinguishableName(boolean show) {
        this.showDistinguishableName = show;
        update();
    }

    public void setShowPosition(boolean show){
        this.showPosition = show;
        update();
    }

    public void setShowReason(boolean show){
        this.showReason = show;
        update();
    }

    public void setPosition(String position) {
        previewData.setLocation(position);
        update();
    }

    public void setReason(String reason) {
        previewData.setReason(reason);
        update();
    }

    public CDigitalSignStyleData getPreviewData() {
        return previewData;
    }

    public void setAlignment(Alignment alignment){
        previewData.setAlignment(alignment);
        update();
        if (alignment == Alignment.left){
            constraintSet.connect(R.id.iv_sign, ConstraintSet.START, ConstraintSet.PARENT_ID, ConstraintSet.START);
            constraintSet.connect(R.id.iv_sign, ConstraintSet.END, R.id.tv_sign_info, ConstraintSet.START);
            constraintSet.connect(R.id.tv_sign_info, ConstraintSet.START, R.id.iv_sign, ConstraintSet.END);
            constraintSet.connect(R.id.tv_sign_info, ConstraintSet.END, ConstraintSet.PARENT_ID, ConstraintSet.END);
        }else {
            constraintSet.connect(R.id.iv_sign, ConstraintSet.START, R.id.tv_sign_info, ConstraintSet.END);
            constraintSet.connect(R.id.iv_sign, ConstraintSet.END, ConstraintSet.PARENT_ID, ConstraintSet.END);
            constraintSet.connect(R.id.tv_sign_info, ConstraintSet.START, ConstraintSet.PARENT_ID, ConstraintSet.START);
            constraintSet.connect(R.id.tv_sign_info, ConstraintSet.END, R.id.iv_sign, ConstraintSet.START);
        }
        TransitionManager.beginDelayedTransition(clPreview);
        constraintSet.applyTo(clPreview);
    }

    private void update() {
        if (previewData != null) {
            if (!TextUtils.isEmpty(previewData.getSignImagePath())) {
                GlideApp.with(getContext())
                        .load(previewData.getSignImagePath())
                        .into(ivSignImage);
            }
            ivSignImage.setVisibility(TextUtils.isEmpty(previewData.getSignImagePath()) ? GONE : VISIBLE);
            ivLogo.setVisibility(showLogo ? VISIBLE : GONE);
            StringBuilder builder = new StringBuilder();
            if (showName){
                appendData(builder, showTab, R.string.tools_field_name, previewData.getName());
            }
            if (!TextUtils.isEmpty(builder) && showDistinguishableName && !TextUtils.isEmpty(previewData.getDigtinguishableName())){
                builder.append("\n");
            }
            if (showDistinguishableName){
                appendData(builder, showTab, R.string.tools_distinguishable_name, previewData.getDigtinguishableName());
            }
            if (!TextUtils.isEmpty(builder) && showReason && !TextUtils.isEmpty(previewData.getReason())){
                builder.append("\n");
            }
            if (showReason){
                appendData(builder, showTab, R.string.tools_reason, previewData.getReason());
            }
            if (!TextUtils.isEmpty(builder) && showPosition && !TextUtils.isEmpty(previewData.getLocation())){
                builder.append("\n");
            }
            if (showPosition){
                appendData(builder, showTab, R.string.tools_location, previewData.getLocation());
            }
            if (!TextUtils.isEmpty(builder) && showDate && !TextUtils.isEmpty(previewData.getDate())){
                builder.append("\n");
            }
            if (showDate){
                appendData(builder, showTab, R.string.tools_date, previewData.getDate());
            }
            if (!TextUtils.isEmpty(builder) && showSDKVersion && !TextUtils.isEmpty(previewData.getSdkVersion())){
                builder.append("\n");
            }
            if (showSDKVersion) {
                appendData(builder, showTab, R.string.tools_compdfkit_versions, previewData.getSdkVersion());
            }
            tvSignInfo.setText(builder);
            if (previewData.getAlignment() == Alignment.left) {
                tvSignInfo.setGravity(Gravity.CENTER_VERTICAL | Gravity.START);
            }else {
                tvSignInfo.setGravity(Gravity.CENTER_VERTICAL | Gravity.END);
            }
        }
    }



    private void appendData(StringBuilder builder, boolean showTab, @StringRes int tabStringResId, String value) {
        if (!TextUtils.isEmpty(value)) {
            if (showTab) {
                builder.append(getString(tabStringResId)).append(": ");
            }
            builder.append(value);
        }
    }

    private String getString(@StringRes int stringResId) {
        return getContext().getString(stringResId);
    }

    public Bitmap getBitmap(){
        buildDrawingCache();
        Bitmap bitmap = Bitmap.createBitmap(getDrawingCache());
        Bitmap resultBitmap = CBitmapUtil.cropTransparent(bitmap);
        return resultBitmap;
    }

    public enum Alignment {
        left,
        right
    }

}
