/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 *
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.forms;


import androidx.constraintlayout.widget.ConstraintSet;

import com.compdfkit.forms.databinding.FormPdfSampleActivityBinding;
import com.compdfkit.tools.common.utils.animation.CFillScreenManager;
import com.compdfkit.tools.common.utils.animation.ConstraintSetUtils;
import com.compdfkit.tools.common.views.pdfview.CPreviewMode;

public class CFormSampleScreenManager {

    private FormPdfSampleActivityBinding binding;

    private CFillScreenManager fillScreenManager = new CFillScreenManager();

    private ConstraintSet constraintSet = new ConstraintSet();

    private ConstraintSetUtils constraintSetUtils = new ConstraintSetUtils();

    private boolean isFillScreen;

    public void bind(FormPdfSampleActivityBinding mainBinding){
        this.binding = mainBinding;
        constraintSet.clone(binding.getRoot());
        fillScreenManager.bindRightToolViewList(binding.pdfView.slideBar);
        fillScreenManager.bindBottomToolViewList(binding.pdfView.indicatorView);
        fillScreenManager.bindBottomToolViewList(binding.formToolBar);
    }


    public void changeWindowStatus(CPreviewMode mode){
        if (mode == CPreviewMode.Viewer){
            fillScreenManager.removeToolView(binding.formToolBar);
            constraintSetUtils.hideFromBottom(constraintSet, binding.formToolBar);
        }else if (mode == CPreviewMode.Form){
            fillScreenManager.bindBottomToolViewList(binding.formToolBar);
            constraintSetUtils.showFromBottom(constraintSet, binding.formToolBar);
        }
        constraintSetUtils.apply(constraintSet, binding.getRoot());
    }

    public void fillScreenChange(){
        fillScreenManager.fillScreenChange(!isFillScreen);
        if (!isFillScreen) {
            //enter full screen
            constraintSetUtils.hideFromTop(constraintSet, binding.flTool);
            constraintSetUtils.hideFromBottom(constraintSet, binding.formToolBar);
            isFillScreen = true;
        } else {
            //enter normal state
            constraintSetUtils.showFromTop(constraintSet, binding.flTool);
            //show bottom annotationBar
            if (fillScreenManager.bottomToolViewList.contains(binding.formToolBar)) {
                constraintSetUtils.showFromBottom(constraintSet, binding.formToolBar);
            }else {
                constraintSetUtils.hideFromBottom(constraintSet, binding.formToolBar);
            }
            isFillScreen = false;
        }
        constraintSetUtils.apply(constraintSet, binding.getRoot());
    }

}
