/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 * <p>
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.viewer;


import androidx.constraintlayout.widget.ConstraintSet;
import androidx.core.view.WindowCompat;
import androidx.core.view.WindowInsetsCompat;
import androidx.core.view.WindowInsetsControllerCompat;
import androidx.fragment.app.FragmentActivity;

import com.compdfkit.tools.common.utils.animation.CFillScreenManager;
import com.compdfkit.tools.common.utils.animation.ConstraintSetUtils;
import com.compdfkit.tools.common.utils.viewutils.CViewUtils;
import com.compdfkit.viewer.databinding.ViewerPdfSampleActivityBinding;

public class CViewerScreenStatusManager {

    private ViewerPdfSampleActivityBinding binding;

    private boolean isFillScreen;

    private ConstraintSet constraintSet = new ConstraintSet();

    private ConstraintSetUtils constraintSetUtils = new ConstraintSetUtils();

    private CFillScreenManager manager = new CFillScreenManager();

    public CViewerScreenStatusManager(ViewerPdfSampleActivityBinding binding) {
        this.binding = binding;
        constraintSet.clone(binding.getRoot());
        manager.bindRightToolViewList(binding.pdfView.slideBar);
        manager.bindBottomToolViewList(binding.pdfView.indicatorView);
    }

    public void fillScreenChange() {
        manager.fillScreenChange(!isFillScreen);
        if (!isFillScreen) {
            //enter full screen
            //hide top toolbar
            constraintSetUtils.hideFromTop(constraintSet, binding.flTool);
            isFillScreen = true;
        } else {
            //enter normal state
            constraintSetUtils.showFromTop(constraintSet, binding.flTool);
            isFillScreen = false;
        }
        constraintSetUtils.apply(constraintSet, binding.getRoot());
    }

    private void setFullScreen() {
        if (binding.pdfView.getContext() instanceof FragmentActivity) {
            FragmentActivity fragmentActivity = (FragmentActivity) binding.pdfView.getContext();
            if (!CViewUtils.isLandScape(binding.pdfView.getContext())) {
                WindowCompat.setDecorFitsSystemWindows(fragmentActivity.getWindow(), false);
            }
            WindowInsetsControllerCompat compat = new WindowInsetsControllerCompat(fragmentActivity.getWindow(), binding.getRoot());
            compat.hide(WindowInsetsCompat.Type.systemBars());
        }
    }

    /**
     * exit full screen
     */
    private void cancelFullScreen() {
        if (binding.pdfView.getContext() instanceof FragmentActivity) {
            FragmentActivity fragmentActivity = (FragmentActivity) binding.pdfView.getContext();
            if (!CViewUtils.isLandScape(binding.pdfView.getContext())) {
                WindowCompat.setDecorFitsSystemWindows(fragmentActivity.getWindow(), true);
            }
            WindowInsetsControllerCompat compat = new WindowInsetsControllerCompat(fragmentActivity.getWindow(), binding.getRoot());
            compat.show(WindowInsetsCompat.Type.systemBars());
        }
    }
}
